/********************************************************************************
 * Copyright (c) 2023 CEA-List
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 ********************************************************************************/

#include "aidge/learning/optimizer/Optimizer.hpp"

Aidge::Optimizer::~Optimizer() noexcept = default;

void Aidge::Optimizer::resetGrad(std::shared_ptr<GraphView> graphView) 
{
    for (auto node : graphView->getNodes())
    {
        auto op = node->getOperator();
        if (op->isAtomic()) {
            auto tensorOp = std::static_pointer_cast<OperatorTensor>(op);
            for (auto outputTensor : tensorOp->getOutputs()) {
                outputTensor->grad()->zeros();
            }
        } else {
            auto metaOp = std::static_pointer_cast<MetaOperator_Op>(op);
            resetGrad(metaOp->getMicroGraph());
        }
    }
}